@@ -44,13 +44,10 @@ static void insert_table_row    (HTMLEngine *e, gboolean after, HTMLTableCell **
 HTMLTable *
 html_engine_get_table (HTMLEngine *e)
 {
-	if (HTML_IS_TABLE (e->cursor->object))
-		return HTML_TABLE (e->cursor->object);
-	else if (!e->cursor->object->parent
-		 || !e->cursor->object->parent->parent
-		 || !e->cursor->object->parent->parent->parent)
-		return NULL;
-	else if (!HTML_IS_TABLE (e->cursor->object->parent->parent->parent))
+	if (!e->cursor->object->parent
+	    || !e->cursor->object->parent->parent
+	    || !e->cursor->object->parent->parent->parent
+	    || !HTML_IS_TABLE (e->cursor->object->parent->parent->parent))
 		return NULL;
 	else
 		return HTML_TABLE (e->cursor->object->parent->parent->parent);
