@@ -24,6 +24,7 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include "gtkhtml.h"
+#include "gtkhtml-stream.h"
 #include "htmltokenizer.h"
 #include "gtkhtml-private.h"
 #include "htmlcolorset.h"
@@ -34,6 +35,7 @@
 #include "htmlsearch.h"
 #include "htmlselection.h"
 #include "htmlsettings.h"
+#include <libgnome/gnome-i18n.h>
 
 #ifndef USE_SCROLLED_WINDOW
 #include <gal/widgets/e-scroll-frame.h>
@@ -471,6 +473,7 @@ html_frame_init (HTMLFrame *frame,
 	GtkHTML   *parent_html;
 	GtkHTMLStream *handle;
 	GtkWidget *scrolled_window;
+	gint depth;
 
 	g_assert (GTK_IS_HTML (parent));
 	parent_html = GTK_HTML (parent);
@@ -499,7 +502,7 @@ html_frame_init (HTMLFrame *frame,
 	gtk_html_set_default_content_type (new_html,
 					   parent_html->priv->content_type);
 	frame->html = new_widget;
-	gtk_html_set_iframe_parent (new_html, parent, HTML_OBJECT (frame));
+	depth = gtk_html_set_iframe_parent (new_html, parent, HTML_OBJECT (frame));
 	gtk_container_add (GTK_CONTAINER (scrolled_window), new_widget);
 	gtk_widget_show (new_widget);
 
@@ -551,8 +554,13 @@ html_frame_init (HTMLFrame *frame,
 	  GTK_SIGNAL_FUNC (frame_button_press_event), frame);
 	*/
 
-	gtk_signal_emit_by_name (GTK_OBJECT (parent_html->engine), 
-				 "url_requested", src, handle);
+	if (depth < 10) {
+		gtk_signal_emit_by_name (GTK_OBJECT (parent_html->engine), 
+					 "url_requested", src, handle);
+	} else {
+		gtk_html_stream_printf (handle, "%s", _("Error: maximium frame depth exceded"));
+		gtk_html_stream_close (handle, GTK_HTML_STREAM_OK);
+	}
 
 	gtk_widget_set_usize (scrolled_window, width, height);
 
