@@ -74,7 +74,7 @@ new_link (HTMLText *t, gint begin, gint end)
 }
 
 static HTMLObject *
-op_copy (HTMLObject *self, HTMLEngine *e, GList *from, GList *to, guint *len)
+op_copy (HTMLObject *self, HTMLObject *parent, HTMLEngine *e, GList *from, GList *to, guint *len)
 {
 	return html_text_op_copy_helper (HTML_TEXT (self), from, to, len, new_link);
 }
@@ -259,17 +259,24 @@ html_link_text_new (const gchar *text,
 	return html_link_text_new_with_len (text, -1, font_style, color, url, target);
 }
 
-void
+HTMLObject *
 html_link_text_to_text (HTMLLinkText *link, HTMLEngine *e)
 {
 	HTMLObject *new_text;
 
 	new_text = html_text_new (HTML_TEXT (link)->text,
-				  GTK_HTML_FONT_STYLE_DEFAULT,
+				  HTML_TEXT (link)->font_style,
 				  html_colorset_get_color (e->settings->color_set, HTMLTextColor));
+	html_text_set_font_face (HTML_TEXT (new_text), HTML_TEXT (link)->face);
 
-	g_warning ("FIXME!!!\n");
-	/* html_engine_replace_by_object (e, HTML_OBJECT (link), 0,
-	   HTML_OBJECT (link), HTML_TEXT (link)->text_len,
-	   new_text); */
+	return new_text;
+}
+
+void
+html_link_text_set_url (HTMLLinkText *link, gchar *url, gchar *target)
+{
+	g_free (link->url);
+	g_free (link->target);
+	link->url = g_strdup (url);
+	link->target = g_strdup (target);
 }
